/**
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package scalapi.itext

import java.io.InputStream
import scalapi.jdk.Implicits._
import com.lowagie.text.pdf.{PRTokeniser, PdfReader}
import scalapi.jdk.control.TakeWhile

class PdfTokenizer {

  def tokenize(pdfStream: InputStream): Seq[String] =
    new PdfReader(pdfStream).use {
      reader =>
        1.to(reader.getNumberOfPages).foldLeft(List.empty[String]) {
          (tokens, pageNum) =>
            val page = reader.getPageContent(pageNum)
            val tokenizer = new PRTokeniser(page)
            val pageTokens = TakeWhile(tokenizer.nextToken)(tokenizer.getStringValue) {
              tokenizer.getTokenType == PRTokeniser.TK_STRING
            }.toList
            tokens ::: pageTokens
        }
    }

}

object PdfTokenizer {

  def tokenize(pdfStream: InputStream): Seq[String] =
    new PdfTokenizer().tokenize(pdfStream)

}